@@ -1,12 +1,8 @@
 package MooseX::Types::Common::Numeric;
-BEGIN {
-  $MooseX::Types::Common::Numeric::AUTHORITY = 'cpan:GRODITI';
-}
-{
-  $MooseX::Types::Common::Numeric::VERSION = '0.001010';
-}
 # ABSTRACT: Commonly used numeric types
 
+our $VERSION = '0.001015';
+
 use strict;
 use warnings;
 
@@ -18,7 +14,9 @@ use MooseX::Types -declare => [
      SingleDigit)
 ];
 
+use Moose ();
 use MooseX::Types::Moose qw/Num Int/;
+use if MooseX::Types->VERSION >= 0.42, 'namespace::autoclean';
 
 subtype PositiveNum,
   as Num,
@@ -134,10 +132,7 @@ __END__
 
 =pod
 
-=encoding utf-8
-
-=for :stopwords Matt S Trout - mst (at) shadowcatsystems.co.uk
-(L<http://www.shadowcatsystems.co.uk/>) K. James Cheetham Guillermo Roditi
+=encoding UTF-8
 
 =head1 NAME
 
@@ -145,7 +140,7 @@ MooseX::Types::Common::Numeric - Commonly used numeric types
 
 =head1 VERSION
 
-version 0.001010
+version 0.001015
 
 =head1 SYNOPSIS
 
@@ -191,17 +186,28 @@ default.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types-Common>
+(or L<bug-MooseX-Types-Common@rt.cpan.org|mailto:bug-MooseX-Types-Common@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHORS
 
 =over 4
 
 =item *
 
-Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
+Matt S Trout - mst (at) shadowcat.co.uk (L<https://www.shadowcat.co.uk/>)
 
 =item *
 
-K. James Cheetham <jamie@shadowcatsystems.co.uk>
+K. James Cheetham <jamie@shadowcat.co.uk>
 
 =item *
 
@@ -211,7 +217,7 @@ Guillermo Roditi <groditi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+This software is copyright (c) 2009 by Matt S Trout - mst (at) shadowcat.co.uk (L<https://www.shadowcat.co.uk/>).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
